/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is LOLfox.
 *
 * The Initial Developer of the Original Code is
 * Jeferson Hultmann <hultmann@gmail.com>
 * Portions created by the Initial Developer are Copyright (C) 2009
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

const EXPORTED_SYMBOLS = ["Translator"];

const Translator = {
  init: function() {
  },
  dispose: function() {
  },
  translate: function(text) {
    return text.replace(/(\w+)/g, replaceWord);
  }
};


function replaceWord(word) {
  var lower = word.toLowerCase();
  var upper = word.toUpperCase();

  var key = ":" + lower; // ":" prefix ==> avoid native properties
  if (Words.hasOwnProperty(key)) {
    lower = Words[key];
  } else {
    lower = katTranzlator(upper).toLowerCase();
  }

  if (word === upper) {
    return lower.toUpperCase();
  }

  if (word[0] === word[0].toUpperCase()) {
    return lower[0].toUpperCase() + lower.substring(1);
  }

  return lower;
}
/*
  Copyright (c) 2008 Dave Dribin

  Permission is hereby granted, free of charge, to any person
  obtaining a copy of this software and associated documentation
  files (the "Software"), to deal in the Software without
  restriction, including without limitation the rights to use, copy,
  modify, merge, publish, distribute, sublicense, and/or sell copies
  of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be
  included in all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
  ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  SOFTWARE.
*/

// http://www.dribin.org/dave/lolspeak/

const Words = {
  ":a": "",
  ":abbatial": "abbashul",
  ":abhorred": "abhorrd",
  ":about": "bout",
  ":absorbed": "absorbd",
  ":abstinential": "abstinenshul",
  ":accelerometer": "accelerometr",
  ":accepts": "acceptz",
  ":access": "acces",
  ":accessibility": "accesibility",
  ":accessories": "accessoriez",
  ":accidential": "accidenshul",
  ":accompanying": "accompanyin",
  ":accomplished": "accomplishd",
  ":according": "accordin",
  ":account": "akownt",
  ":accounting": "accouting",
  ":accrementitial": "accrementishul",
  ":accumulating": "accumulatin",
  ":accusation": "accusashun",
  ":accustomed": "accustomd",
  ":achilles": "achillez",
  ":acquired": "acquird",
  ":acquiring": "acquirin",
  ":acquisition": "acquizishun",
  ":across": "acros",
  ":action": "akshun",
  ":actions": "akshuns",
  ":actual": "akshul",
  ":actually": "akshully",
  ":added": "addd",
  ":adding": "addin",
  ":addition": "addishun",
  ":additions": "addishuns",
  ":address": "addres",
  ":addresses": "addressez",
  ":adds": "addz",
  ":administration": "administrashun",
  ":admission": "admishun",
  ":admitted": "admittd",
  ":adopters": "adopterz",
  ":ads": "adz",
  ":advanced": "advancd",
  ":advantages": "advantagez",
  ":advential": "advenshul",
  ":advertisers": "advertiserz",
  ":advertising": "advertisin",
  ":advised": "advisd",
  ":advisors": "advisorz",
  ":affiliation": "affiliashun",
  ":aforelinked": "aforelinkd",
  ":aforementioned": "aforemenshuned",
  ":after": "aftr",
  ":agential": "agenshul",
  ":ages": "agez",
  ":agreed": "agred",
  ":agrees": "agreez",
  ":agrestial": "agresshul",
  ":aims": "aimz",
  ":airs": "airz",
  ":airtunes": "airtunez",
  ":allowed": "allowd",
  ":allowing": "allowin",
  ":allows": "allowz",
  ":alpha": "alfa",
  ":alternating": "alternatin",
  ":alternative": "alternativ",
  ":alternatives": "alternativez",
  ":always": "alwayz",
  ":amazing": "amazin",
  ":analyzing": "analyzin",
  ":anchored": "anchord",
  ":and": "an",
  ":animated": "animatd",
  ":animation": "animashun",
  ":animations": "animashuns",
  ":annoucing": "annoucin",
  ":announced": "announcd",
  ":announcing": "announcin",
  ":annoyed": "annoyd",
  ":annoying": "annoyin",
  ":another": "anothr",
  ":answer": "anzwr",
  ":answered": "anzwerd",
  ":answering": "answerin",
  ":answers": "anzwrs",
  ":anteinitial": "anteinishul",
  ":antenatalitial": "antenatalishul",
  ":antialiasing": "antialiasin",
  ":anticipated": "anticipatd",
  ":anticipation": "anticipashun",
  ":antipestilential": "antipestilenshul",
  ":antiprudential": "antiprudenshul",
  ":anything": "anythin",
  ":aperature": "aperschur",
  ":apologies": "apologiez",
  ":apostrophe": "apostrofe",
  ":appalling": "appallin",
  ":appealed": "appeald",
  ":appeared": "appeard",
  ":appears": "appearz",
  ":application": "applicashun",
  ":applications": "applicashuns",
  ":applies": "appliez",
  ":approved": "approvd",
  ":approving": "approvin",
  ":apps": "appz",
  ":aquantive": "aquantiv",
  ":architecture": "architecchur",
  ":archive": "archiv",
  ":are": "r",
  ":argued": "argud",
  ":arising": "arisin",
  ":arrived": "arrivd",
  ":articles": "articlez",
  ":asisted": "assistd",
  ":asked": "askd",
  ":asking": "askin",
  ":asks": "askz",
  ":assembling": "assemblin",
  ":assets": "assetz",
  ":assimilation": "assimilashun",
  ":associated": "associatd",
  ":assumed": "assumd",
  ":assuming": "assumin",
  ":assumption": "assumpshun",
  ":astonishing": "astonishin",
  ":astounding": "astoundin",
  ":atrophy": "atrofy",
  ":attached": "attachd",
  ":attacker": "attackr",
  ":attacks": "attackz",
  ":attempted": "attemptd",
  ":attempting": "attemptin",
  ":attendees": "attendeez",
  ":attention": "attenshun",
  ":attitudes": "attitudez",
  ":authentication": "authenticashun",
  ":authored": "authord",
  ":authorities": "authoritiez",
  ":authorized": "authorizd",
  ":authors": "authorz",
  ":autosaving": "autosavin",
  ":avoiding": "avoidin",
  ":awesome": "awsum",
  ":back": "bak",
  ":backed": "backd",
  ":background": "bakground",
  ":backing": "backin",
  ":backup": "bakup",
  ":backups": "backupz",
  ":baffled": "baffld",
  ":baked": "bakd",
  ":balanopreputial": "balanoprepushul",
  ":balked": "balkd",
  ":balkled": "balkd",
  ":ballmer": "ballmr",
  ":bandwidth": "bandwif",
  ":banker": "bankr",
  ":banking": "bankin",
  ":banning": "bannin",
  ":based": "basd",
  ":bastards": "bastardz",
  ":be": "bees",
  ":beaing": "bean",
  ":beaking": "breakin",
  ":because": "cuz",
  ":becomes": "becomez",
  ":before": "b4",
  ":beginning": "beginnin",
  ":beijing": "beijin",
  ":being": "bein",
  ":beleaguered": "beleaguerd",
  ":believe": "bleev",
  ":believes": "believez",
  ":believing": "believin",
  ":belongs": "belongz",
  ":benchmarks": "benchmarkz",
  ":bends": "bendz",
  ":beneficential": "beneficenshul",
  ":benefits": "benefitz",
  ":bestial": "besshul",
  ":betrays": "betrayz",
  ":better": "bettr",
  ":between": "tween",
  ":bidential": "bidenshul",
  ":big": "hooj",
  ":bigential": "bigenshul",
  ":bigger": "biggr",
  ":billboards": "billboardz",
  ":billed": "billd",
  ":binaries": "binariez",
  ":birthday": "birfdai",
  ":bitangential": "bitangenshul",
  ":blocks": "blockz",
  ":bloggers": "bloggerz",
  ":blogging": "bloggin",
  ":blows": "blowz",
  ":board": "bord",
  ":boing": "boin",
  ":book's": "bookz",
  ":booked": "bookd",
  ":bookies": "bookiez",
  ":bookmarks": "bookmarkz",
  ":books": "bookz",
  ":bootlegged": "bootleggd",
  ":bootlegging": "bootleggin",
  ":borders": "borderz",
  ":boring": "borin",
  ":boss": "bos",
  ":bought": "buyd",
  ":bow": "bowage",
  ":boy": "boi",
  ":branching": "branchin",
  ":branded": "brandd",
  ":branding": "brandin",
  ":breaks": "breakz",
  ":breed": "bred",
  ":brewed": "brewd",
  ":bricks": "brickz",
  ":briefed": "briefd",
  ":brightness": "brightnes",
  ":bring": "brin",
  ":bringing": "bringin",
  ":brings": "bringz",
  ":broken": "brokd",
  ":browser": "browsr",
  ":browsers": "browserz",
  ":browsing": "browsin",
  ":building": "buildin",
  ":burned": "burnd",
  ":burrows": "burrowz",
  ":business": "busines",
  ":businessweek": "businesweek",
  ":busted": "bustd",
  ":buying": "buyin",
  ":buys": "buyz",
  ":bye": "kthxbye",
  ":cables": "cablez",
  ":cadential": "cadenshul",
  ":calculated": "calculatd",
  ":called": "calld",
  ":calling": "callin",
  ":calls": "callz",
  ":candidates": "candidatez",
  ":canned": "cannd",
  ":cans": "canz",
  ":capillitial": "capillishul",
  ":capitalization": "capitalizashun",
  ":capping": "cappin",
  ":caps": "capz",
  ":capture": "capchure",
  ":captured": "capturd",
  ":cardinalitial": "cardinalishul",
  ":carrier": "carrir",
  ":cars": "carz",
  ":cat": "kitteh",
  ":caucuses": "caucusez",
  ":caution": "caushun",
  ":celebrating": "celebratin",
  ":celestial": "celesshul",
  ":cellphone": "cellfone",
  ":center": "centr",
  ":cents": "sents",
  ":challenges": "challengez",
  ":champions": "championz",
  ":changed": "changd",
  ":changes": "changez",
  ":changing": "changin",
  ":channels": "channelz",
  ":characters": "characterz",
  ":charged": "chargd",
  ":charges": "chargez",
  ":charging": "chargin",
  ":chatter": "chattr",
  ":cheaper": "cheapr",
  ":checking": "checkin",
  ":cheer": "cher",
  ":cheeseburger": "cheezburger",
  ":cheeseburgers": "cheezburgers",
  ":chipped": "chippd",
  ":choose": "chooz",
  ":choosing": "choosin",
  ":christopher": "christophr",
  ":circumferential": "circumferenshul",
  ":circumspatial": "circumspashul",
  ":circumstantial": "circumstanshul",
  ":cited": "citd",
  ":cities": "citiez",
  ":claims": "claimz",
  ":class": "clas",
  ":clearer": "clearr",
  ":clever": "clevr",
  ":clicking": "clickin",
  ":clients": "clientz",
  ":closes": "closez",
  ":closing": "closin",
  ":coders": "coderz",
  ":coding": "codin",
  ":coeffluential": "coeffluenshul",
  ":coessential": "coessenshul",
  ":coincides": "coincidez",
  ":coinitial": "coinishul",
  ":collaboration": "collaborashun",
  ":colleagues": "colleaguez",
  ":collection": "collecshun",
  ":collections": "collecshuns",
  ":collects": "collectz",
  ":columns": "columnz",
  ":combination": "combinashun",
  ":comes": "comez",
  ":coming": "comin",
  ":comitial": "comishul",
  ":commands": "commandz",
  ":comments": "commentz",
  ":commercial": "commershul",
  ":commercials": "commershuls",
  ":commission": "commishun",
  ":communicated": "speekd",
  ":communicating": "communicatin",
  ":commuter": "commutr",
  ":companies": "companiez",
  ":compares": "comparez",
  ":comparing": "comparin",
  ":compelling": "compellin",
  ":compensation": "compensashun",
  ":competing": "competin",
  ":competition": "competishun",
  ":competitors": "competitorz",
  ":compilation": "compilashun",
  ":compiled": "compild",
  ":complacential": "complacenshul",
  ":complained": "complaind",
  ":complaining": "complainin",
  ":complains": "complainz",
  ":complaints": "complaintz",
  ":completed": "completd",
  ":complicated": "complicatd",
  ":components": "componentz",
  ":comprised": "comprisd",
  ":compromise": "compromize",
  ":compromised": "compromisd",
  ":computer": "computr",
  ":computers": "computerz",
  ":computing": "computin",
  ":concerns": "concernz",
  ":concluded": "concludd",
  ":concludes": "concludez",
  ":conclusion": "conclushun",
  ":concordantial": "concordanshul",
  ":condenses": "condensez",
  ":condition": "condishun",
  ":conditions": "condishuns",
  ":conferential": "conferenshul",
  ":confessing": "confessin",
  ":confidential": "confidenshul",
  ":configuration": "configurashun",
  ":confines": "confinez",
  ":confirmation": "confirmashun",
  ":confirmed": "confirmd",
  ":confronted": "confrontd",
  ":confusion": "confushun",
  ":congratulations": "congratulashuns",
  ":congress": "congres",
  ":congruential": "congruenshul",
  ":connected": "connectd",
  ":connection": "connecshun",
  ":connections": "connecshuns",
  ":consciousness": "consciousnes",
  ":consequential": "consequenshul",
  ":consider": "considr",
  ":considerations": "considerashuns",
  ":considered": "considerd",
  ":considering": "considerin",
  ":considers": "considerz",
  ":considred": "considerd",
  ":consiousness": "sonsciousnes",
  ":consists": "consistz",
  ":consortial": "consorshul",
  ":constrained": "constraind",
  ":consubstantial": "consubstanshul",
  ":consulting": "consultin",
  ":consumer": "consumr",
  ":consumers": "consumerz",
  ":consumes": "consumez",
  ":consuming": "consumin",
  ":consummated": "consummatd",
  ":contacted": "contactd",
  ":contains": "containz",
  ":contangential": "contangenshul",
  ":contents": "contentz",
  ":contingential": "contingenshul",
  ":continued": "continud",
  ":continues": "continuez",
  ":contradiction": "contradicshun",
  ":contrived": "contrivd",
  ":controlled": "controlld",
  ":controller": "controllr",
  ":controls": "controlz",
  ":controversial": "controvershul",
  ":convention": "convenshun",
  ":conventional": "convenshunal",
  ":conversation": "conversashun",
  ":conversions": "convershuns",
  ":converted": "convertd",
  ":convinced": "convincd",
  ":coordinates": "coordinatez",
  ":coordination": "coordinashun",
  ":copied": "copid",
  ":copies": "copiez",
  ":corporation": "corporashun",
  ":correspondential": "correspondenshul",
  ":costs": "costz",
  ":cotangential": "cotangenshul",
  ":could": "cud",
  ":covering": "coverin",
  ":covers": "coverz",
  ":cracking": "crackin",
  ":crapped": "crappd",
  ":creaks": "creakz",
  ":created": "creatd",
  ":creating": "creatin",
  ":creation": "creashun",
  ":creations": "creashuns",
  ":credential": "credenshul",
  ":credentials": "credenshuls",
  ":crendital": "credenshul",
  ":criticism": "critisizm",
  ":critics": "criticz",
  ":crossed": "crossd",
  ":crowes": "crowez",
  ":crowned": "crownd",
  ":crumbling": "crumblin",
  ":cubes": "cubez",
  ":curatial": "curashul",
  ":customer": "customr",
  ":customers": "customerz",
  ":cutter": "cuttr",
  ":cutting": "cuttin",
  ":damages": "damagez",
  ":danger": "dangr",
  ":daring": "darin",
  ":day": "dai",
  ":days": "dais",
  ":dead": "ded",
  ":deals": "dealz",
  ":debuted": "debutd",
  ":december": "decembr",
  ":deception": "decepshun",
  ":decided": "decidd",
  ":decides": "decidez",
  ":deciding": "decidin",
  ":decision": "decishun",
  ":decisions": "decishuns",
  ":decrypting": "decryptin",
  ":dedicated": "dedicatd",
  ":deduction": "deducshun",
  ":deductions": "deducshuns",
  ":defaults": "defaultz",
  ":defeats": "defeatz",
  ":defective": "defectiv",
  ":deferential": "deferenshul",
  ":deficiencies": "deficienciez",
  ":defining": "definin",
  ":definition": "definishun",
  ":definitions": "definishuns",
  ":delays": "delayz",
  ":delicious": "delishus",
  ":deliver": "delivr",
  ":delivered": "deliverd",
  ":delivering": "deliverin",
  ":delivers": "deliverz",
  ":delphi": "delfi",
  ":demanding": "demandin",
  ":demographics": "demographicz",
  ":demos": "demoz",
  ":denver": "denvr",
  ":denying": "denyin",
  ":dependencies": "dependenciez",
  ":deposition": "deposishun",
  ":depreciation": "depreciashun",
  ":depressing": "depresin",
  ":described": "describd",
  ":describes": "describez",
  ":description": "descripshun",
  ":descriptions": "descripshuns",
  ":deserved": "deservd",
  ":deserves": "deservez",
  ":designed": "designd",
  ":designer": "designr",
  ":designers": "designerz",
  ":designing": "designin",
  ":designs": "designz",
  ":desperation": "desperashun",
  ":destined": "destind",
  ":destroyed": "destroyd",
  ":detailed": "detaild",
  ":details": "detailz",
  ":determination": "determinashun",
  ":determined": "determind",
  ":developed": "developd",
  ":developer": "developr",
  ":developers": "developrz",
  ":developing": "developin",
  ":devices": "devicez",
  ":didn't": "didnt",
  ":died": "did",
  ":differences": "differencez",
  ":differencing": "differencin",
  ":differential": "differenshul",
  ":digging": "diggin",
  ":digitizing": "digitizin",
  ":diluted": "dilutd",
  ":dimension": "dimenshun",
  ":dinner": "dinnr",
  ":dipped": "dippd",
  ":direction": "direcshun",
  ":directions": "direcshuns",
  ":directories": "directoriez",
  ":directors": "directorz",
  ":disabled": "diabld",
  ":disagreeing": "disagreein",
  ":disappearing": "disapperin",
  ":disappointed": "disappointd",
  ":disappointing": "disappointin",
  ":discounted": "discountd",
  ":discovered": "discoverd",
  ":discussion": "discushun",
  ":discussions": "discushuns",
  ":disliked": "dislikd",
  ":dismiss": "dismis",
  ":dismissed": "dismissd",
  ":dismisses": "dismisez",
  ":dismissing": "dismissin",
  ":disorder": "disordr",
  ":dispatches": "dispatchez",
  ":displayed": "displayd",
  ":displays": "displayz",
  ":disputed": "disputd",
  ":distinction": "distincshun",
  ":distributed": "distributd",
  ":distribution": "distribushun",
  ":ditched": "ditchd",
  ":division": "divishun",
  ":divisions": "divishuns",
  ":do": "doez",
  ":docs": "docz",
  ":doctored": "doctord",
  ":documentation": "documentashun",
  ":dodging": "dodgin",
  ":does": "doez",
  ":dogged": "doggd",
  ":doing": "doin",
  ":dollars": "dollarz",
  ":don't": "dun",
  ":donation": "donashun",
  ":donations": "donashuns",
  ":done": "dun",
  ":doomed": "doomd",
  ":doors": "doorz",
  ":doubled": "doubld",
  ":doubters": "doubterz",
  ":doubting": "doubtin",
  ":downgrading": "downgradin",
  ":downloading": "downloadin",
  ":downloads": "downloadz",
  ":dressed": "dressd",
  ":drive": "driv",
  ":drivers": "driverz",
  ":drives": "drivez",
  ":driving": "drivin",
  ":dropped": "droppd",
  ":drops": "dropz",
  ":drowned": "drownd",
  ":during": "durin",
  ":dvds": "dvdz",
  ":eagles": "eaglez",
  ":earlier": "earlir",
  ":easier": "easir",
  ":eclipsing": "eclipsin",
  ":economics": "economicz",
  ":edges": "edgez",
  ":editing": "editin",
  ":edition": "edishun",
  ":editors": "editorz",
  ":edits": "editz",
  ":education": "edumacashun",
  ":edwards": "edwardz",
  ":effects": "effectz",
  ":either": "eithr",
  ":election": "elecshun",
  ":electropotential": "electropotenshul",
  ":elements": "elementz",
  ":elmer": "elmr",
  ":elongated": "elongatd",
  ":eloquential": "eloquenshul",
  ":emailed": "emaild",
  ":emerging": "emergin",
  ":emphasis": "emfasiz",
  ":emphasizing": "emphasizin",
  ":employed": "employd",
  ":employees": "employeez",
  ":emulation": "emulashun",
  ":emulations": "emulashuns",
  ":enabled": "enabld",
  ":enables": "enablez",
  ":enabling": "enablin",
  ":encountering": "encounterin",
  ":encourages": "encouragez",
  ":encouraging": "encouragin",
  ":encryption": "encrypshun",
  ":endeavors": "endeavorz",
  ":ended": "endd",
  ":ending": "endin",
  ":endless": "endles",
  ":endorsed": "endorsd",
  ":endorses": "endorsez",
  ":endorsing": "endorsin",
  ":ends": "endz",
  ":enemies": "enemiez",
  ":engineering": "engineerin",
  ":engineers": "engineerz",
  ":enhanced": "enhancd",
  ":enhances": "enhanez",
  ":enjoyed": "enjoyd",
  ":enjoying": "enjoyin",
  ":enlightened": "enlightend",
  ":enter": "entr",
  ":entrenched": "entrenchd",
  ":entries": "entriez",
  ":enumeration": "enumerashun",
  ":epididymodeferential": "epididymodeferenshul",
  ":equation": "equashun",
  ":equidistantial": "equidistanshul",
  ":equinoctial": "equinocshul",
  ":equipotential": "equipotenshul",
  ":equipped": "equippd",
  ":equispatial": "equispashul",
  ":equitangential": "equitangenshul",
  ":errors": "errorz",
  ":escaping": "escapin",
  ":essential": "essenshul",
  ":established": "establishd",
  ":establishing": "establishin",
  ":ether": "ethr",
  ":eucharistial": "eucharisshul",
  ":euphemisms": "eufemisms",
  ":evaluating": "evaluatin",
  ":events": "eventz",
  ":eventually": "evenshully",
  ":ever": "evr",
  ":every": "evry",
  ":everyone": "evryone",
  ":everything": "everythin",
  ":evidential": "evidenshul",
  ":evokes": "evokez",
  ":evolution": "evolushun",
  ":evolving": "evolvin",
  ":exactly": "egsaktly",
  ":examination": "examinashun",
  ":examples": "examplez",
  ":exasperated": "exasperatd",
  ":excellent": "awsum",
  ":exception": "excepshun",
  ":excited": "excitd",
  ":exciting": "excitin",
  ":excrementitial": "excrementishul",
  ":excrescential": "excrescenshul",
  ":executing": "executin",
  ":executive": "executiv",
  ":executives": "executivez",
  ":exhaustive": "exhaustiv",
  ":existed": "existd",
  ":existential": "existenshul",
  ":existing": "existin",
  ":exists": "existz",
  ":expanded": "expandd",
  ":expanding": "expandin",
  ":expected": "expectd",
  ":expediential": "expedienshul",
  ":expenditures": "expenditurez",
  ":experienced": "experiencd",
  ":experiences": "experiencez",
  ":experiential": "experienshul",
  ":explained": "explaind",
  ":explains": "explainz",
  ":explanation": "explanashun",
  ":explanations": "explanashuns",
  ":exponential": "exponenshul",
  ":exported": "exportd",
  ":express": "expres",
  ":expression": "expreshun",
  ":expressions": "expreshuns",
  ":extends": "extendz",
  ":extensions": "extenshuns",
  ":extensive": "extensiv",
  ":extraessential": "extraessenshul",
  ":fabrication": "fabricashun",
  ":faces": "facez",
  ":factitial": "factishul",
  ":factories": "factoriez",
  ":factors": "factorz",
  ":failed": "faild",
  ":failing": "failin",
  ":failures": "failurez",
  ":fake": "faek",
  ":fans": "fanz",
  ":fascinating": "fascintatin",
  ":faster": "fastr",
  ":fastscripts": "fastscriptz",
  ":feathers": "featherz",
  ":feature": "feachur",
  ":featured": "featurd",
  ":features": "featurez",
  ":featuring": "featurin",
  ":feed": "fed",
  ":feel": "feelz",
  ":feeling": "feelin",
  ":feels": "feelz",
  ":fees": "feez",
  ":fetial": "feshul",
  ":fever": "fevr",
  ":fewer": "fewr",
  ":fiddling": "fiddlin",
  ":figures": "figurez",
  ":figuring": "figurin",
  ":filed": "fild",
  ":files": "filez",
  ":filter": "filtr",
  ":financial": "finanshul",
  ":finder": "findr",
  ":finding": "findin",
  ":fingers": "fingerz",
  ":finished": "finishd",
  ":fired": "fird",
  ":first": "furst",
  ":fitness": "fitnes",
  ":fits": "fitz",
  ":fiver": "fivr",
  ":fixed": "fixd",
  ":fixes": "fixez",
  ":fixing": "fixin",
  ":flavored": "flavord",
  ":flawed": "flawd",
  ":floating": "floatin",
  ":focused": "focusd",
  ":folder": "foldr",
  ":folks": "folkz",
  ":following": "followin",
  ":fonts": "fontz",
  ":football": "futball",
  ":for": "4",
  ":forced": "forcd",
  ":forcing": "forcin",
  ":foregoing": "foregoin",
  ":forestial": "foresshul",
  ":formats": "formatz",
  ":formatted": "formattd",
  ":formed": "formd",
  ":former": "formr",
  ":forms": "formz",
  ":fortunes": "fortunez",
  ":forums": "forumz",
  ":found": "findz",
  ":foundation": "foundashun",
  ":four": "4",
  ":foxytunes": "foxytunez",
  ":frames": "framez",
  ":fraser": "frasr",
  ":friday": "fridai",
  ":fried": "frid",
  ":friend": "frend",
  ":friends": "frenz",
  ":from": "frum",
  ":frommer": "frommr",
  ":front": "frunt",
  ":frontier": "frontir",
  ":frustrated": "frustratd",
  ":frying": "fryin",
  ":fuck": "f&^%",
  ":fucking": "f&^%ing",
  ":fueled": "fueld",
  ":full": "fol",
  ":function": "funcshun",
  ":functions": "funcshuns",
  ":furnished": "furnishd",
  ":further": "furthr",
  ":galleries": "galleriez",
  ":games": "gamez",
  ":gaping": "gapin",
  ":gartner": "gartnr",
  ":gatekeeper": "gatekeepr",
  ":gave": "gaev",
  ":gawker": "gawkr",
  ":generated": "generatd",
  ":generates": "generatez",
  ":generating": "generatin",
  ":generation": "generashun",
  ":gentilitial": "gentilishul",
  ":gestures": "gesturez",
  ":get": "git",
  ":gets": "getz",
  ":getting": "gettin",
  ":giant": "hooj",
  ":giants": "giantz",
  ":ginned": "ginnd",
  ":girl": "gurl",
  ":give": "giv",
  ":gives": "givez",
  ":giving": "givin",
  ":gloating": "gloatin",
  ":glorified": "glorifid",
  ":goes": "goez",
  ":going": "goin",
  ":good": "gud",
  ":goodies": "goodiez",
  ":graggers": "graggerz",
  ":graphed": "grafd",
  ":graphic": "grafic",
  ":graphics": "grafic",
  ":gratification": "gratificashun",
  ":greater": "greatr",
  ":gripped": "grippd",
  ":groans": "groanz",
  ":grounds": "groundz",
  ":growing": "growin",
  ":grows": "growz",
  ":gruber": "groober",
  ":guaranteed": "guaranted",
  ":guess": "gues",
  ":guessed": "guessd",
  ":guessing": "guessin",
  ":guided": "guidd",
  ":guts": "gutz",
  ":guys": "guyz",
  ":hacking": "hackin",
  ":half": "haf",
  ":handed": "handd",
  ":handicaps": "handicapz",
  ":handles": "handlez",
  ":hands": "hanz",
  ":hanging": "hangin",
  ":happend": "happend",
  ":happened": "happend",
  ":happening": "happenin",
  ":happens": "happenz",
  ":happy": "happeh",
  ":harder": "hardr",
  ":have": "has",
  ":having": "havin",
  ":head": "hed",
  ":headed": "headd",
  ":heading": "headin",
  ":heads": "headz",
  ":heard": "herd",
  ":hearing": "hearin",
  ":hearings": "hearingz",
  ":heartwarming": "heartwarmin",
  ":hearwarming": "heartwarmin",
  ":heels": "heelz",
  ":hello": "y halo thar",
  ":help": "halp",
  ":helped": "helpd",
  ":helping": "helpin",
  ":helps": "helpz",
  ":here": "her",
  ":here's": "heers",
  ":heroes": "heroez",
  ":hi": "oh hai",
  ":higher": "highr",
  ":highlight": "highlite",
  ":highlighting": "highlightin",
  ":highlights": "highlightz",
  ":himself": "him",
  ":hints": "hintz",
  ":hired": "hird",
  ":his": "hims",
  ":hits": "hitz",
  ":holder": "holdr",
  ":holders": "holderz",
  ":holding": "holdin",
  ":holdings": "holdingz",
  ":holds": "holdz",
  ":holiday": "holidai",
  ":holidays": "holidais",
  ":hoped": "hopd",
  ":hopelessly": "hopelesly",
  ":hoping": "hopin",
  ":hosting": "hostin",
  ":hours": "hourz",
  ":house": "houz",
  ":hovering": "hoverin",
  ":however": "howevr",
  ":hughes": "hughez",
  ":humorless": "humorles",
  ":hundred": "hundrd",
  ":hundreds": "hundredz",
  ":hunger": "hungr",
  ":hurdles": "hurdlez",
  ":hurts": "hurtz",
  ":hyperreverential": "hyperreverenshul",
  ":hyperspatial": "hyperspashul",
  ":i'm": "me",
  ":i've": "i has",
  ":icons": "iconz",
  ":ideas": "ideaz",
  ":identified": "identifid",
  ":idiots": "idiotz",
  ":illusion": "illushun",
  ":illustration": "illustrashun",
  ":imacs": "imacz",
  ":images": "imagez",
  ":imaging": "imagin",
  ":imaginig": "imaginin",
  ":imagining": "imaginin",
  ":impartial": "imparshul",
  ":implementation": "implementashun",
  ":implemented": "implementd",
  ":implied": "implid",
  ":implies": "impliez",
  ":impressed": "impresd",
  ":impressions": "impreshuns",
  ":improve": "improov",
  ":improved": "improovd",
  ":improvements": "improovements",
  ":imprudential": "imprudenshul",
  ":inception": "incepshun",
  ":inches": "inchez",
  ":included": "includd",
  ":includes": "includez",
  ":including": "includin",
  ":inconsequential": "inconsequenshul",
  ":increased": "increasd",
  ":increases": "increasez",
  ":increasing": "increasin",
  ":indeed": "inded",
  ":indentation": "indentashun",
  ":indentations": "indentashuns",
  ":indicated": "indicatd",
  ":indicates": "indicatez",
  ":indifferential": "indifferenshul",
  ":individuals": "individualz",
  ":indulgential": "indulgenshul",
  ":inequipotential": "inequipotenshul",
  ":inertial": "inershul",
  ":inessential": "inessenshul",
  ":infection": "infecshun",
  ":infects": "infectz",
  ":inferential": "inferenshul",
  ":influenced": "influencd",
  ":influential": "influenshul",
  ":infographic": "infografic",
  ":information": "informashun",
  ":informed": "informd",
  ":infrabestial": "infrabesshul",
  ":infracelestial": "infracelesshul",
  ":infuriating": "infriatin",
  ":initial": "inishul",
  ":injection": "injecshun",
  ":innocent": "innosent",
  ":inquirer": "inquirr",
  ":inspection": "inspecshun",
  ":inspiration": "inspirashun",
  ":inspired": "inspird",
  ":inspiring": "inspirin",
  ":installation": "installashun",
  ":installations": "installashuns",
  ":installed": "installd",
  ":installer": "installr",
  ":installing": "installin",
  ":instantial": "instanshul",
  ":instruction": "instrucshun",
  ":instructions": "instrucshuns",
  ":insubstantial": "insubstanshul",
  ":integrated": "integratd",
  ":integrates": "integratez",
  ":integration": "integrashn",
  ":integrodifferential": "integrodifferenshul",
  ":intelligential": "intelligenshul",
  ":intended": "intendd",
  ":intentions": "intenshuns",
  ":interaction": "interacshun",
  ":interactive": "interactiv",
  ":interequinoctial": "interequinocshul",
  ":interested": "interestd",
  ":interesting": "interestin",
  ":interfaces": "interfacez",
  ":interfacing": "interfacin",
  ":interferential": "interferenshul",
  ":intergential": "intergenshul",
  ":internet": "internets",
  ":internuptial": "internupshul",
  ":interpolation": "interpolashun",
  ":interpolations": "interpolashuns",
  ":interspatial": "interspashul",
  ":interstitial": "interstishul",
  ":interviews": "interviewz",
  ":introduced": "introducd",
  ":introduces": "introducez",
  ":introducing": "introducin",
  ":introduction": "introducshun",
  ":inverts": "invertz",
  ":invested": "investd",
  ":investigating": "investigatin",
  ":investigative": "investigativ",
  ":investors": "investorz",
  ":invokes": "invokez",
  ":involved": "involvd",
  ":iphone": "ifone",
  ":iphonedrive": "ifonedrive",
  ":iphones": "ifonez",
  ":iphoto": "ifoto",
  ":ipods": "ipodz",
  ":irredential": "irredenshul",
  ":irreverential": "irreverenshul",
  ":is": "iz",
  ":isn't": "isnt",
  ":isolated": "isolatd",
  ":issues": "issuez",
  ":it's": "iz",
  ":items": "itemz",
  ":iterating": "iteratin",
  ":its": "itz",
  ":itunes": "itunez",
  ":jackass": "jackas",
  ":jackassyness": "jackasynes",
  ":james": "jamez",
  ":jaws": "jawz",
  ":jesus": "jebus",
  ":jibes": "jibez",
  ":jiminy": "omgwtfbbq",
  ":jobs": "jobz",
  ":joined": "joind",
  ":joining": "joinin",
  ":joking": "jokin",
  ":jones": "jonez",
  ":jostling": "jostlin",
  ":journalists": "journalistz",
  ":judged": "judgd",
  ":judging": "judgin",
  ":jumped": "jumpd",
  ":jumping": "jumpin",
  ":jurisprudential": "jurisprudenshul",
  ":just": "jus",
  ":keeping": "keepin",
  ":keeps": "keepz",
  ":keyboards": "keyboardz",
  ":keys": "keyz",
  ":keywords": "keywordz",
  ":kicking": "kickin",
  ":kidding": "kiddin",
  ":kids": "kidz",
  ":killed": "killd",
  ":killer": "killr",
  ":know": "knoe",
  ":knows": "knowz",
  ":labeled": "labeld",
  ":labeling": "labelin",
  ":labelled": "labeld",
  ":labels": "labelz",
  ":laboratories": "laboratoriez",
  ":labs": "labz",
  ":ladies": "ladiez",
  ":landed": "landd",
  ":laptops": "laptopz",
  ":larger": "largr",
  ":laser": "lazr",
  ":later": "latr",
  ":latter": "lattr",
  ":laugh": "laff",
  ":launched": "launchd",
  ":laws": "lawz",
  ":layers": "layerz",
  ":layouts": "layoutz",
  ":lazytwitter": "lazytwittr",
  ":leaders": "leaderz",
  ":leading": "leadin",
  ":leaks": "leakz",
  ":learned": "learnd",
  ":learning": "lernin",
  ":leave": "leef",
  ":legislature": "legislachur",
  ":legs": "legz",
  ":lens": "lenz",
  ":leopard": "lepprd",
  ":less": "les",
  ":lets": "letz",
  ":letter": "lettr",
  ":letters": "letterz",
  ":levels": "levelz",
  ":leveraging": "leveragin",
  ":levereaging": "leveragin",
  ":licensed": "licensd",
  ":licensing": "licensin",
  ":like": "liek",
  ":liked": "likd",
  ":limitation": "limitashun",
  ":limitations": "limitashuns",
  ":limited": "limitd",
  ":limits": "limitz",
  ":lined": "lind",
  ":lines": "linez",
  ":lingering": "lingerin",
  ":linkblogging": "linkbloggin",
  ":links": "linkz",
  ":listened": "listend",
  ":lists": "listz",
  ":little": "lil",
  ":live": "liv",
  ":living": "livin",
  ":loaded": "loadd",
  ":loading": "loadin",
  ":localised": "localisd",
  ":location": "locashun",
  ":logicians": "logicianz",
  ":logs": "logz",
  ":longer": "longr",
  ":looked": "lookd",
  ":looking": "lukingz",
  ":looks": "lookz",
  ":losing": "losin",
  ":lots": "lawts",
  ":love": "luv",
  ":loved": "lovd",
  ":lovely": "luvly",
  ":loves": "luvz",
  ":lucrative": "lucrativ",
  ":lunistitial": "lunistishul",
  ":lying": "lyin",
  ":macbooks": "macbookz",
  ":machine": "masheen",
  ":machines": "masheens",
  ":macs": "macz",
  ":magazines": "magazinez",
  ":mailboxes": "mailboxez",
  ":maintained": "maintaind",
  ":maintaining": "maintainin",
  ":make": "mak",
  ":maker": "makr",
  ":makers": "makerz",
  ":makes": "makez",
  ":making": "makin",
  ":malicious": "malishus",
  ":manager": "managr",
  ":managers": "managerz",
  ":manages": "managez",
  ":managing": "managin",
  ":manipulation": "manipulashun",
  ":manning": "manning",
  ":manufacture": "manufacchur",
  ":manufacturing": "manufacturin",
  ":many": "lotz da",
  ":mapping": "mappin",
  ":maps": "mapz",
  ":market": "markit",
  ":marketing": "marketin",
  ":markets": "marketz",
  ":marshals": "marshalz",
  ":martial": "marshul",
  ":masks": "maskz",
  ":mass": "mas",
  ":matter": "mattr",
  ":mattered": "matterd",
  ":maximizing": "maximizin",
  ":may": "cud",
  ":meaning": "meanin",
  ":means": "meanz",
  ":measures": "measurez",
  ":measuring": "measurin",
  ":mechanisms": "mechanismz",
  ":meeting": "mettin",
  ":megaphone": "megafone",
  ":member": "membr",
  ":members": "memberz",
  ":memoirs": "memoirz",
  ":memory": "mems",
  ":mention": "menshun",
  ":mentioned": "menshund",
  ":merchandise": "merchandize",
  ":mess": "mes",
  ":message": "mesage",
  ":messages": "mesagez",
  ":messenger": "messengr",
  ":migration": "migrashun",
  ":minded": "mindd",
  ":minds": "mindz",
  ":miniaturization": "miniaturizashun",
  ":minutes": "minutez",
  ":minutial": "minushul",
  ":mischaracterization": "mischaracterizashun",
  ":misd": "missd",
  ":misleading": "misleadin",
  ":miss": "mis",
  ":missed": "misd",
  ":misses": "misez",
  ":missing": "missin",
  ":mission": "mishun",
  ":missions": "mishuns",
  ":mistakes": "mistakez",
  ":misunderstanding": "misunderstandin",
  ":mocking": "mockn",
  ":models": "modelz",
  ":monday": "mondai",
  ":months": "monthz",
  ":more": "moar",
  ":morning": "mornin",
  ":mother": "mothr",
  ":motion": "moshun",
  ":move": "moov",
  ":moved": "movd",
  ":moves": "movez",
  ":movies": "moviez",
  ":moving": "movin",
  ":mr": "mistah",
  ":much": "mutch",
  ":multiuser": "multiusr",
  ":my": "mah",
  ":naked": "nakd",
  ":name": "naym",
  ":named": "namd",
  ":names": "namez",
  ":nation": "nashun",
  ":nationwide": "nashunwide",
  ":nature": "nachur",
  ":need": "ned",
  ":needed": "needd",
  ":needs": "needz",
  ":negotiations": "negotiashuns",
  ":neither": "neithr",
  ":network": "netwerk",
  ":never": "nevr",
  ":new": "nu",
  ":news": "newz",
  ":newsletter": "newslettr",
  ":newspaper": "nespapr",
  ":nomination": "nominashun",
  ":noncelestial": "noncelesshul",
  ":nonconfidential": "nonconfidenshul",
  ":nondeferential": "nondeferenshul",
  ":nonessential": "nonessenshul",
  ":nonetheless": "nonetheles",
  ":nonevidential": "nonevidenshul",
  ":nonexistential": "nonexistenshul",
  ":noninitial": "noninishul",
  ":nonmartial": "nonmarshul",
  ":nonpartial": "nonparshul",
  ":nonpotential": "nonpotenshul",
  ":nonpreferential": "nonpreferenshul",
  ":nonpresidential": "nonpresidenshul",
  ":nonprovidential": "nonprovidenshul",
  ":nonresidential": "nonresidenshul",
  ":nonserviential": "nonservienshul",
  ":nonsubstantial": "nonsubstanshul",
  ":nontangential": "nontangenshul",
  ":notes": "notez",
  ":nothing": "nothin",
  ":noticed": "noticd",
  ":notification": "notificashun",
  ":notifications": "notificashuns",
  ":noting": "notin",
  ":notion": "noshun",
  ":november": "novembr",
  ":novitial": "novishul",
  ":now": "nao",
  ":nowadays": "nowadais",
  ":nuclear": "nucular",
  ":nuggets": "nuggetz",
  ":number": "numbr",
  ":numbered": "numbrd",
  ":numbers": "numberz",
  ":nuptial": "nupshul",
  ":nutritial": "nutrishul",
  ":nytimes": "nytimez",
  ":obediential": "obedienshul",
  ":objected": "objectd",
  ":objections": "objecshuns",
  ":obligation": "obligashun",
  ":observation": "observashun",
  ":observations": "observashuns",
  ":observer": "observr",
  ":observers": "observerz",
  ":obtained": "obtaind",
  ":obtaining": "obtainin",
  ":obviating": "obviatin",
  ":occasional": "occashunal",
  ":occasionally": "occashunally",
  ":occasions": "occashuns",
  ":occurring": "occurrin",
  ":october": "octobr",
  ":of": "ov",
  ":offended": "offendd",
  ":offer": "offr",
  ":offered": "offrd",
  ":offering": "offerin",
  ":offers": "offerz",
  ":oh": "o",
  ":ok": "k",
  ":omission": "omishun",
  ":one": "wan",
  ":ones": "onez",
  ":ongoing": "ongoin",
  ":opening": "openin",
  ":opens": "openz",
  ":operating": "operatin",
  ":operation": "operashun",
  ":operations": "operashuns",
  ":opinions": "opinionz",
  ":opposed": "opposd",
  ":optimized": "optimizd",
  ":option": "opshun",
  ":optional": "opshunal",
  ":optionally": "opshunally",
  ":options": "opshuns",
  ":order": "ordr",
  ":ordered": "orderd",
  ":orders": "orderz",
  ":oriented": "orientd",
  ":ostial": "osshul",
  ":other": "othr",
  ":others": "otherz",
  ":otherwise": "otherwize",
  ":our": "r",
  ":outliner": "outlinr",
  ":outstanding": "outstandin",
  ":over": "ovar",
  ":overcarged": "overchargd",
  ":overheating": "overheatin",
  ":overinfluential": "overinfluenshul",
  ":overlooked": "overlookd",
  ":overpartial": "overparshul",
  ":overpotential": "overpotenshul",
  ":overpowered": "overpowerd",
  ":overrated": "overratd",
  ":overrepresented": "overrepresentd",
  ":overriding": "overridin",
  ":overtures": "overturez",
  ":overwhelming": "overwhelmin",
  ":owed": "owd",
  ":owned": "ownd",
  ":owner": "ownr",
  ":owners": "ownerz",
  ":owns": "ownz",
  ":packaging": "packagin",
  ":page": "paeg",
  ":pages": "pagez",
  ":pageviews": "pageviewz",
  ":palatial": "palashul",
  ":panning": "pannin",
  ":pants": "pantz",
  ":paper": "papr",
  ":paragraph": "paragraf",
  ":parallels": "parallelz",
  ":parameter": "parametr",
  ":parses": "parsez",
  ":parsing": "parsin",
  ":partial": "parshul",
  ":participated": "participatd",
  ":partitioning": "partitionin",
  ":partners": "partnerz",
  ":parts": "partz",
  ":pass": "pas",
  ":passengers": "passengerz",
  ":passes": "pasez",
  ":passwords": "passwordz",
  ":patents": "patentz",
  ":patriots": "patriotz",
  ":penitential": "penitenshul",
  ":people": "peeps",
  ":percent": "persent",
  ":perfect": "perfik",
  ":performed": "performd",
  ":performs": "performz",
  ":perhaps": "perhapz",
  ":perichaetial": "perichaeshul",
  ":pericytial": "pericyshul",
  ":peripheral": "periferal",
  ":perkins": "perkinz",
  ":permission": "permishun",
  ":permissions": "permishuns",
  ":perplexed": "perplexd",
  ":persons": "personz",
  ":perspective": "perspectiv",
  ":pestilential": "pestilenshul",
  ":peter": "petr",
  ":phil": "fil",
  ":philadelphia": "filadelfia",
  ":philip": "filip",
  ":phill": "fill",
  ":philosophy": "filosofy",
  ":phone": "fone",
  ":phones": "fonez",
  ":photo": "foto",
  ":photograph": "fotograf",
  ":photographers": "fotografers",
  ":photographic": "fotografic",
  ":photographs": "fotografs",
  ":photonic": "fotonic",
  ":photos": "fotos",
  ":photoshop": "fotoshop",
  ":phrase": "frase",
  ":phrasing": "frasin",
  ":physical": "fysical",
  ":physicist": "fysicist",
  ":physics": "fysics",
  ":picked": "pickd",
  ":picking": "pickin",
  ":picks": "pickz",
  ":pictures": "picturez",
  ":pieces": "piecez",
  ":pinching": "pinchin",
  ":pirated": "piratd",
  ":places": "placez",
  ":plagued": "plagud",
  ":planning": "plannin",
  ":plans": "planz",
  ":platforms": "platformz",
  ":played": "playd",
  ":player": "playr",
  ":players": "playerz",
  ":playing": "playin",
  ":plays": "playz",
  ":playstation": "playstashun",
  ":please": "plz",
  ":pleasing": "pleasin",
  ":plenipotential": "plenipotenshul",
  ":plugging": "pluggin",
  ":plugins": "pluginz",
  ":podcasts": "podcastz",
  ":pointing": "pointin",
  ":points": "pointz",
  ":polling": "pollin",
  ":pondering": "ponderin",
  ":pops": "popz",
  ":portals": "portalz",
  ":ported": "portd",
  ":portion": "porshun",
  ":portions": "porshuns",
  ":ports": "portz",
  ":position": "posishun",
  ":positive": "positiv",
  ":possession": "posesshun",
  ":possibilities": "possibilitiez",
  ":possible": "posible",
  ":postcomitial": "postcomishul",
  ":posted": "postd",
  ":poster": "postr",
  ":postnuptial": "postnupshul",
  ":posts": "postz",
  ":potential": "potenshul",
  ":pounced": "pouncd",
  ":power": "powr",
  ":powered": "powerd",
  ":praises": "praisez",
  ":precedential": "precedenshul",
  ":preceding": "precedin",
  ":precious": "preshus",
  ":predicted": "predictd",
  ":predicting": "predictin",
  ":prediction": "predicshun",
  ":prefatial": "prefashul",
  ":prefer": "prefr",
  ":preferences": "preferencez",
  ":preferential": "preferenshul",
  ":preferred": "preferrd",
  ":prefs": "prefz",
  ":preinitial": "preinishul",
  ":prelatial": "prelashul",
  ":prenuptial": "prenupshul",
  ":preparation": "preparashun",
  ":preparations": "preparashuns",
  ":prepotential": "prepotenshul",
  ":preprocessing": "preprocessin",
  ":preputial": "prepushul",
  ":presentation": "presentashun",
  ":presentations": "presentashuns",
  ":presential": "presenshul",
  ":presention": "presenshun",
  ":president": "prezident",
  ":presidential": "presidenshul",
  ":press": "pres",
  ":pressing": "pressin",
  ":presubstantial": "presubstanshul",
  ":preteressential": "preteressenshul",
  ":preternuptial": "preternupshul",
  ":pretty": "pritee",
  ":prevented": "preventd",
  ":prevents": "preventz",
  ":priced": "pricd",
  ":prices": "pricez",
  ":primaries": "primariez",
  ":primatial": "primashul",
  ":primitial": "primishul",
  ":principles": "principlez",
  ":printed": "printd",
  ":printing": "printin",
  ":priorities": "prioritiez",
  ":privileged": "privilegd",
  ":privileges": "privilegez",
  ":prizes": "prizez",
  ":problems": "problemz",
  ":proceed": "proced",
  ":process": "proces",
  ":processing": "processin",
  ":proclaiming": "proclaimin",
  ":produced": "producd",
  ":producer": "producr",
  ":produces": "producez",
  ":production": "producshun",
  ":products": "productz",
  ":professional": "profeshunal",
  ":professionals": "profeshunals",
  ":profressional": "profeshunal",
  ":profressionals": "profeshunals",
  ":programming": "programmin",
  ":progress": "progres",
  ":projects": "projectz",
  ":promising": "promisun",
  ":promoting": "promotin",
  ":promotional": "promoshunal",
  ":proper": "propr",
  ":properties": "propertiez",
  ":propitial": "propishul",
  ":prospects": "prospectz",
  ":protective": "protectiv",
  ":protuberantial": "protuberanshul",
  ":proves": "provez",
  ":provided": "providd",
  ":providential": "providenshul",
  ":provider": "providr",
  ":provides": "providez",
  ":providing": "providin",
  ":proving": "provin",
  ":prudential": "prudenshul",
  ":pseudoimpartial": "pseudoimparshul",
  ":publication": "publicashun",
  ":publications": "publicashuns",
  ":publishers": "publisherz",
  ":publishes": "publishez",
  ":publishing": "publishin",
  ":pulled": "pulld",
  ":pulling": "pullin",
  ":pulls": "pullz",
  ":pumping": "pumpin",
  ":purchased": "purchasd",
  ":purported": "purportd",
  ":purposes": "purposez",
  ":pursuing": "pursuin",
  ":pushed": "pushd",
  ":pussy": "pusy",
  ":putting": "puttin",
  ":puutting": "puttin",
  ":quarter": "quartr",
  ":quarters": "quarterz",
  ":querulential": "querulenshul",
  ":question": "queshun",
  ":questions": "queshuns",
  ":queued": "queud",
  ":quicksilver": "quicksilvr",
  ":quintessential": "quintessenshul",
  ":quitting": "quittin",
  ":radioactive": "radioactiv",
  ":rails": "railz",
  ":raised": "raisd",
  ":raises": "raisez",
  ":rands": "randz",
  ":ranks": "rankz",
  ":rather": "rathr",
  ":rating": "ratin",
  ":reached": "reachd",
  ":reaction": "reacshun",
  ":reader": "readr",
  ":readers": "readerz",
  ":reading": "readin",
  ":reads": "readz",
  ":realizing": "realizin",
  ":really": "rly",
  ":reasons": "reasonz",
  ":recalls": "recallz",
  ":receipts": "receiptz",
  ":received": "receivd",
  ":receiver": "receivr",
  ":recent": "resent",
  ":reception": "recepshun",
  ":recodring": "recordin",
  ":recommended": "recommendd",
  ":recorder": "recordr",
  ":recording": "recordin",
  ":recrementitial": "recrementishul",
  ":recurring": "recurrin",
  ":reducing": "reducin",
  ":reduction": "reducshun",
  ":referential": "referenshul",
  ":referring": "referrin",
  ":refusing": "refusin",
  ":regarding": "regardin",
  ":regardless": "regardles",
  ":register": "registr",
  ":reinforcing": "reinforcin",
  ":rejected": "rejectd",
  ":rejection": "rejecshun",
  ":related": "relatd",
  ":relations": "relashuns",
  ":relatives": "relativez",
  ":released": "releasd",
  ":releases": "releasez",
  ":releasing": "releasin",
  ":remaining": "remainin",
  ":remains": "remainz",
  ":remarks": "remarkz",
  ":remember": "remembr",
  ":reminder": "remindr",
  ":reminding": "remindin",
  ":reminds": "remindz",
  ":reminiscential": "reminiscenshul",
  ":removed": "removd",
  ":render": "rendr",
  ":rendering": "rendrin",
  ":renowned": "renownd",
  ":rented": "rentd",
  ":repairing": "repairin",
  ":repeated": "repeatd",
  ":repeats": "repeatz",
  ":repercussions": "repercushuns",
  ":replied": "replid",
  ":replies": "repliez",
  ":reporing": "reportin",
  ":reported": "reportd",
  ":reporting": "reportin",
  ":reports": "reportz",
  ":representatives": "representativez",
  ":representing": "representin",
  ":requested": "requestd",
  ":required": "requird",
  ":requirements": "requirementz",
  ":requires": "requirez",
  ":requiring": "requirin",
  ":resentations": "presentashuns",
  ":residential": "residenshul",
  ":residents": "residentz",
  ":resisting": "resistn",
  ":resolution": "resolushun",
  ":resolved": "resolvd",
  ":resources": "resourcez",
  ":respected": "respectd",
  ":responds": "respondz",
  ":responses": "responsez",
  ":restless": "restles",
  ":restoration": "restorashun",
  ":restriction": "restricshun",
  ":restrictions": "restricshuns",
  ":resulted": "resultd",
  ":results": "resultz",
  ":retailer": "retailr",
  ":retained": "retaind",
  ":retention": "retenshun",
  ":retial": "reshul",
  ":reveals": "revealz",
  ":revenues": "revenuez",
  ":reverential": "reverenshul",
  ":reverses": "reversez",
  ":reviewed": "reviewd",
  ":reviews": "reviewz",
  ":revises": "revisez",
  ":revolution": "revolushun",
  ":revolutionary": "revolushunary",
  ":rewards": "rewardz",
  ":rewriting": "rewritin",
  ":ridiculous": "redikulus",
  ":right": "rite",
  ":ripper": "rippr",
  ":ripping": "rippin",
  ":risks": "riskz",
  ":robbed": "robbd",
  ":robotics": "roboticz",
  ":rodential": "rodenshul",
  ":rolling": "rollin",
  ":rotation": "rotashun",
  ":rows": "rowz",
  ":ruffling": "rufflin",
  ":rugged": "ruggd",
  ":rules": "rulez",
  ":rumored": "rumord",
  ":rumors": "rumorz",
  ":running": "runnin",
  ":runs": "runz",
  ":said": "sed",
  ":sales": "salez",
  ":sampling": "samplin",
  ":sanctioned": "sancshund",
  ":sandwiches": "sandwichez",
  ":sans": "sanz",
  ":sapiential": "sapienshul",
  ":sarbanes": "sarbanez",
  ":satisfaction": "satisfacshun",
  ":satisfying": "satisfyin",
  ":saturday": "katurdai",
  ":saving": "savin",
  ":savviness": "savvines",
  ":say": "sai",
  ":saying": "sayin",
  ":says": "sez",
  ":scaling": "scalin",
  ":scared": "skerd",
  ":scarification": "scarificashun",
  ":scathing": "scathin",
  ":scenes": "scneez",
  ":scheduled": "scheduld",
  ":scheduling": "schedulin",
  ":schizophrenia": "schizofrenia",
  ":schools": "schoolz",
  ":sciential": "scienshul",
  ":sclerotial": "scleroshul",
  ":score": "skor",
  ":scored": "scord",
  ":screencasting": "screencastin",
  ":screenshots": "screenshotz",
  ":screwed": "screwd",
  ":screws": "screwz",
  ":script": "skript",
  ":scripting": "scriptin",
  ":scripts": "scriptz",
  ":scripture": "scripchur",
  ":scrolling": "scrollin",
  ":seamless": "seamles",
  ":searches": "searchez",
  ":searching": "searchin",
  ":seating": "seatin",
  ":seats": "seatz",
  ":seconds": "secondz",
  ":secret": "seekret",
  ":secrets": "seekretz",
  ":section": "secshun",
  ":sections": "secshuns",
  ":see": "c",
  ":seeded": "seedd",
  ":seeds": "seedz",
  ":seeing": "seein",
  ":seeking": "seekin",
  ":seeks": "seekz",
  ":seemed": "seemd",
  ":seems": "seemz",
  ":sees": "seez",
  ":selected": "selectd",
  ":selecting": "selectin",
  ":selection": "selecshun",
  ":self's": "selfs",
  ":selling": "sellin",
  ":sells": "sellz",
  ":semicelestial": "semicelesshul",
  ":sending": "sendin",
  ":sentential": "sentenshul",
  ":separation": "separashun",
  ":sepbember": "septembr",
  ":sequential": "sequenshul",
  ":series": "seriez",
  ":seriously": "srsly",
  ":served": "servd",
  ":server": "servr",
  ":servers": "servrz",
  ":serves": "servez",
  ":service": "survis",
  ":services": "servicez",
  ":serviential": "servienshul",
  ":sesquitertial": "sesquitershul",
  ":session": "seshun",
  ":sessions": "seshuns",
  ":settings": "settingz",
  ":shared": "shard",
  ":shareholder": "shareholdr",
  ":shareholders": "shareholderz",
  ":shares": "sharez",
  ":sharing": "sharin",
  ":sheds": "shedz",
  ":shipped": "shippd",
  ":shipping": "shippin",
  ":ships": "shipz",
  ":shitting": "shittin",
  ":shocking": "shockin",
  ":shortcomings": "shortcomingz",
  ":shortcuts": "shortcutz",
  ":shorter": "shortr",
  ":should": "shud",
  ":showed": "showd",
  ":showing": "showin",
  ":shows": "showz",
  ":shrinks": "shrinkz",
  ":sidelines": "sidelinez",
  ":signals": "signalz",
  ":signing": "signin",
  ":signs": "signz",
  ":signups": "signupz",
  ":silential": "silenshul",
  ":silver": "silvr",
  ":sinking": "sinkin",
  ":site": "siet",
  ":sites": "siets",
  ":situation": "situashun",
  ":situations": "situashuns",
  ":six": "6",
  ":sized": "sizd",
  ":sketching": "sketchin",
  ":skewed": "skewd",
  ":slides": "slidez",
  ":slimmed": "slimmd",
  ":slower": "slowr",
  ":slumping": "slumpin",
  ":smaller": "smallr",
  ":smartphone": "smartfone",
  ":smells": "smellz",
  ":smudged": "smudgd",
  ":smuggled": "smuggld",
  ":soaked": "soakd",
  ":social": "soshul",
  ":soldering": "solderin",
  ":solstitial": "solstishul",
  ":solution": "solushun",
  ":solutions": "solushuns",
  ":solved": "solvd",
  ":some": "sum",
  ":something": "somethin",
  ":sometimes": "sometimez",
  ":sophisticated": "sofisticatd",
  ":sorry": "sry",
  ":sounding": "soundin",
  ":sounds": "soundz",
  ":sources": "sourcez",
  ":sourcing": "sourcin",
  ":spaces": "spacez",
  ":spangled": "spangld",
  ":spatial": "spashul",
  ":speakers": "speakerz",
  ":speaking": "speakin",
  ":specced": "speccd",
  ":special": "speshul",
  ":specialized": "specializd",
  ":specification": "specificashun",
  ":specifications": "specificashuns",
  ":specs": "specz",
  ":spectators": "spectatorz",
  ":specter": "spectr",
  ":speculating": "speculatin",
  ":speculation": "speculashun",
  ":specutlitve": "speculativ",
  ":speed": "sped",
  ":spends": "spendz",
  ":spoilers": "spoilerz",
  ":sponsoring": "sponsorin",
  ":sporting": "sportin",
  ":spreading": "spreadin",
  ":spreads": "spreadz",
  ":spreadsheets": "spreadsheetz",
  ":sprinkles": "sprinklez",
  ":squeezed": "squeezd",
  ":stacks": "stackz",
  ":standardized": "standardizd",
  ":standards": "standardz",
  ":stands": "standz",
  ":starbucks": "starbuckz",
  ":stars": "starz",
  ":started": "startd",
  ":starting": "startin",
  ":starts": "startz",
  ":stashing": "stashin",
  ":stated": "statd",
  ":states": "statez",
  ":station": "stashun",
  ":stations": "stashuns",
  ":stats": "statz",
  ":staying": "stayin",
  ":stays": "stayz",
  ":steal": "steel",
  ":stealing": "stealin",
  ":stephenson": "stefenson",
  ":stepped": "steppd",
  ":steps": "stepz",
  ":sticking": "stickin",
  ":stocked": "stockd",
  ":stocks": "stockz",
  ":stored": "stord",
  ":stores": "storez",
  ":stories": "storiez",
  ":strained": "straind",
  ":strapped": "strappd",
  ":strategies": "strategiez",
  ":streaming": "streamin",
  ":streamlined": "streamlind",
  ":strengths": "strengthz",
  ":strikes": "strikez",
  ":striking": "strikin",
  ":string": "strin",
  ":strips": "stripz",
  ":stronger": "strongr",
  ":structure": "strucchur",
  ":struggled": "struggld",
  ":students": "studentz",
  ":stunning": "stunnin",
  ":subcelestial": "subcelesshul",
  ":subessential": "subessenshul",
  ":subinitial": "subinishul",
  ":subintelligential": "subintelligenshul",
  ":submissions": "submishuns",
  ":subscribers": "subscriberz",
  ":subscription": "subscripshun",
  ":subsequential": "subsequenshul",
  ":subsistential": "subsistenshul",
  ":substantial": "substanshul",
  ":substring": "substrin",
  ":subtercelestial": "subtercelesshul",
  ":subversion": "subvershun",
  ":succeed": "succed",
  ":succeeds": "succeedz",
  ":success": "succes",
  ":sucks": "suckz",
  ":suffer": "suffr",
  ":suffers": "sufferz",
  ":suggested": "suggestd",
  ":suggestions": "sugesshuns",
  ":suggests": "suggestz",
  ":suited": "suitd",
  ":summarizes": "summarizez",
  ":super": "supr",
  ":supercelestial": "supercelesshul",
  ":superduper": "superdupr",
  ":superessential": "superessenshul",
  ":superintendential": "superintendenshul",
  ":supersesquitertial": "supersesquitershul",
  ":supersubstantial": "supersubstanshul",
  ":supplied": "supplid",
  ":suppliers": "supplierz",
  ":supported": "supportd",
  ":supporters": "supporterz",
  ":supports": "supportz",
  ":supposed": "supposd",
  ":suprise": "surprize",
  ":surfing": "surfin",
  ":surprised": "surprisd",
  ":surprises": "surprisez",
  ":surprising": "surprisn",
  ":surrounding": "surroundin",
  ":sutied": "suitd",
  ":sweater": "sweatr",
  ":swelled": "swelld",
  ":switched": "switchd",
  ":switches": "switchez",
  ":switching": "switchin",
  ":swizzling": "swizzlin",
  ":synching": "synchin",
  ":syncytial": "syncyshul",
  ":system": "sistem",
  ":sytems": "sistemz",
  ":tagging": "taggin",
  ":take": "taek",
  ":takeover": "takeovr",
  ":takes": "takez",
  ":taking": "takin",
  ":takover": "takeovr",
  ":talented": "talentd",
  ":talked": "talkd",
  ":talking": "talkin",
  ":talks": "talkz",
  ":tangential": "tangenshul",
  ":tapes": "tapez",
  ":taping": "tapin",
  ":targeting": "targetin",
  ":targets": "targetz",
  ":tasks": "taskz",
  ":tasting": "tastin",
  ":teaching": "teachin",
  ":teams": "teamz",
  ":techniques": "techniquez",
  ":technologies": "technologiez",
  ":telephotos": "telefotoz",
  ":telestial": "telesshul",
  ":telling": "tellin",
  ":tendential": "tendenshul",
  ":teretial": "tereshul",
  ":terms": "termz",
  ":tertial": "tershul",
  ":tester": "testr",
  ":testing": "testin",
  ":tests": "testz",
  ":textwrangler": "textwranglr",
  ":thanks": "thx",
  ":that": "dat",
  ":the": "teh",
  ":theater": "theatr",
  ":their": "der",
  ":themselves": "themselvez",
  ":there": "thar",
  ":these": "thees",
  ":thing": "ting",
  ":things": "tings",
  ":think": "finks",
  ":thinking": "thinkin",
  ":thinkpads": "thinkpadz",
  ":thinnes": "thinnes",
  ":this": "dis",
  ":those": "dose",
  ":thought": "thot",
  ":thoughts": "thoughtz",
  ":thousands": "thousandz",
  ":three": "3",
  ":thrives": "thrivez",
  ":thriving": "thrivin",
  ":through": "thru",
  ":throwing": "throwin",
  ":thursday": "thursdai",
  ":tiered": "tierd",
  ":tiering": "tierin",
  ":tiles": "tilez",
  ":time": "tiem",
  ":times": "tiems",
  ":timing": "timin",
  ":tinker": "tinkr",
  ":titles": "titlez",
  ":to": "2",
  ":today": "todai",
  ":together": "togehtr",
  ":tomorrow": "2morrow",
  ":tonight": "tonite",
  ":too": "2",
  ":tools": "toolz",
  ":topics": "topicz",
  ":torrential": "torrenshul",
  ":tossup": "tosup",
  ":totipotential": "totipotenshul",
  ":touches": "touchez",
  ":touted": "toutd",
  ":towards": "towardz",
  ":tower": "towr",
  ":toys": "toyz",
  ":tracking": "trackin",
  ":trackpads": "trackpadz",
  ":tracks": "trackz",
  ":traction": "tracshun",
  ":trademarks": "trademarkz",
  ":tradional": "tradishunal",
  ":trafficked": "traffickd",
  ":transaction": "transacshun",
  ":transcript": "tranzscript",
  ":transexperiential": "transexperienshul",
  ":transfer": "transfr",
  ":transferential": "transferenshul",
  ":transformation": "transformashun",
  ":transition": "transishun",
  ":translate": "tranzlate",
  ":translated": "translatd",
  ":translation": "translashun",
  ":translator": "tranzlator",
  ":transmitted": "transmittd",
  ":transubstantial": "transubstanshul",
  ":treated": "treatd",
  ":trekked": "trekkd",
  ":triangulation": "triangulashun",
  ":tribunitial": "tribunishul",
  ":tricks": "trickz",
  ":tried": "trid",
  ":triggering": "triggerin",
  ":trimming": "trimmin",
  ":trinoctial": "trinocshul",
  ":tritangential": "tritangenshul",
  ":troubled": "troubld",
  ":troubling": "troublin",
  ":trying": "tryin",
  ":tuesday": "tuesdai",
  ":turned": "turnd",
  ":turns": "turnz",
  ":tweaking": "tweakin",
  ":tweeted": "tweetd",
  ":tweets": "tweetz",
  ":twitter": "twittr",
  ":two": "2",
  ":tying": "tyin",
  ":typing": "typin",
  ":typograhy": "tyopgrafy",
  ":typography": "typografy",
  ":unanchored": "unanchord",
  ":unanswered": "unanzwerd",
  ":unapproved": "unapprovd",
  ":unboxing": "unboxin",
  ":uncelestial": "uncelesshul",
  ":uncircumstantial": "uncircumstanshul",
  ":unconfidential": "unconfidenshul",
  ":unconsequential": "unconsequenshul",
  ":undefeated": "undefeatd",
  ":undeferential": "undeferenshul",
  ":under": "undr",
  ":underlying": "underlyin",
  ":underpowered": "underpowerd",
  ":underscores": "underscorez",
  ":understanding": "understandin",
  ":undertaking": "undertakin",
  ":undervalued": "undervalud",
  ":undifferential": "undifferenshul",
  ":unessential": "unessenshul",
  ":unevidential": "unevidenshul",
  ":unexpected": "unexpectd",
  ":unexperiential": "unexperienshul",
  ":unimpartial": "unimparshul",
  ":uninfluential": "uninfluenshul",
  ":unipotential": "unipotenshul",
  ":united": "unitd",
  ":units": "unitz",
  ":unless": "unles",
  ":unlocked": "unlockd",
  ":unlocking": "unlockin",
  ":unmartial": "unmarshul",
  ":unnamed": "unnamd",
  ":unpalatial": "unpalashul",
  ":unpartial": "unparshul",
  ":unpestilential": "unpestilenshul",
  ":unprecedential": "unprecedenshul",
  ":unpresidential": "unpresidenshul",
  ":unprovidential": "unprovidenshul",
  ":unreverential": "unreverenshul",
  ":unsequential": "unsequenshul",
  ":unsolicited": "unsolicitd",
  ":unspatial": "unspashul",
  ":unsubstantial": "unsubstanshul",
  ":untangential": "untangenshul",
  ":until": "til",
  ":unveiled": "unveild",
  ":unwise": "unwize",
  ":upcoming": "upcomin",
  ":updated": "updatd",
  ":updates": "updatez",
  ":upgraded": "upgradd",
  ":upgrades": "upgradez",
  ":uploads": "uploadz",
  ":upper": "uppr",
  ":upscaled": "upscald",
  ":used": "usd",
  ":useless": "useles",
  ":user": "usr",
  ":users": "userz",
  ":uses": "usez",
  ":using": "usin",
  ":utilities": "utilitiez",
  ":utter": "uttr",
  ":vader": "vadr",
  ":variables": "variablez",
  ":vending": "vendin",
  ":ventripotential": "ventripotenshul",
  ":version": "vershun",
  ":versionable": "vershunable",
  ":versions": "vershuns",
  ":very": "vary",
  ":videos": "videoz",
  ":videotapes": "videotapez",
  ":videotaping": "videotapin",
  ":viewed": "viewd",
  ":viewers": "viewerz",
  ":vindicated": "vindicatd",
  ":violations": "violashuns",
  ":virtualization": "virtualizashun",
  ":vision": "vishun",
  ":visionless": "vishunles",
  ":visions": "vishuns",
  ":visited": "visietd",
  ":visualization": "visualizashun",
  ":vivisectin": "vivisecshun",
  ":voters": "voterz",
  ":voting": "votin",
  ":vowed": "vowd",
  ":waiting": "waitin",
  ":waking": "wakin",
  ":want": "wants",
  ":wanted": "wantd",
  ":wanting": "wantin",
  ":wants": "wantz",
  ":warming": "warmin",
  ":warned": "warnd",
  ":warner": "warnr",
  ":warranties": "warrantiez",
  ":wars": "warz",
  ":was": "wuz",
  ":watching": "watchin",
  ":watered": "waterd",
  ":way": "wai",
  ":ways": "wayz",
  ":we'll": "well",
  ":we're": "were",
  ":weakness": "weaknes",
  ":wearing": "wearin",
  ":weather": "weathr",
  ":webapps": "webappz",
  ":website": "websiet",
  ":websites": "websiets",
  ":weekday": "weekdai",
  ":weeks": "weekz",
  ":welcome": "welcom",
  ":were": "wuz",
  ":weren't": "wuz not",
  ":what": "wut",
  ":whatever": "whatevr",
  ":whatsoever": "whatsoevr",
  ":whenever": "whenevr",
  ":where": "wer",
  ":whether": "whethr",
  ":whipped": "whippd",
  ":who": "hoo",
  ":whoever": "whoevr",
  ":why": "y",
  ":widgets": "widgetz",
  ":wiggling": "wigglin",
  ":willing": "willin",
  ":windows": "windowz",
  ":winner": "winnr",
  ":winners": "winnerz",
  ":winning": "winnin",
  ":wins": "winz",
  ":wired": "wird",
  ":wished": "wishd",
  ":wishes": "wishez",
  ":with": "wif",
  ":wnated": "wantd",
  ":wonder": "wondr",
  ":wondering": "wonderin",
  ":word": "werd",
  ":wordpress": "werdpres",
  ":words": "werdz",
  ":work": "werk",
  ":workaround": "werkaround",
  ":worked": "werkd",
  ":worker": "werkr",
  ":working": "werkin",
  ":works": "werkz",
  ":workstation": "workstashun",
  ":workstations": "werkstashuns",
  ":world": "wurld",
  ":worst": "wurst",
  ":worth": "wurth",
  ":would": "wud",
  ":write": "rite",
  ":writer": "writr",
  ":writes": "writez",
  ":writing": "writin",
  ":written": "writteh",
  ":yards": "yardz",
  ":yeah": "ya",
  ":year": "yer",
  ":years": "yeers",
  ":yes": "yez",
  ":yesterday": "yesterdai",
  ":you": "u",
  ":you'd": "ud",
  ":younger": "youngr",
  ":your": "ur",
  ":yours": "urz",
  ":zoocytial": "zoocyshul",
  ":zoomer": "zoomr",
  ":zooming": "zommin"
};
// Copyright (C) 2008 Google Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview
 * Translates English into LOLCat.  Inspired by lolspeak.org.
 *
 * @author mikesamuel@gmail.com
 */

/**
 * @param {string} upper English
 * @return {string} LOLCAT
 */
function katTranzlator(upper) {
  /*
      .replace(new RegExp('\\s+', 'g'), ' ')
      .replace(new RegExp('^ +| +$', 'g'), '')*/;
  for (var i = 0, n = TRANSFORMATIONS.length; i < n; i += 2) {
    upper = upper.replace(TRANSFORMATIONS[i], TRANSFORMATIONS[i + 1]);
  }

  return upper;
}

var TRANSFORMATIONS = [
/*
  new RegExp('\bCAN (I|YOU|HE|SHE|IT|WE|THEY)\b', 'g'), '$1 CAN',

  new RegExp('\bTO\b', 'g'), '2',
  new RegExp('\bFOR\b', 'g'), '4',
  new RegExp('\bYOUR\b', 'g'), 'UR',
  new RegExp('\bYOU\b', 'g'), 'U',
  new RegExp('\bTHIS\b', 'g'), 'DIS',
  new RegExp('\bWITH\b', 'g'), 'WIF',
  new RegExp('\bHAVE\b', 'g'), 'HAZ',
  new RegExp('\bARE\b', 'g'), 'IS',
  new RegExp('\bAM\b', 'g'), 'IS',
  new RegExp('\bPLEASE\b', 'g'), 'PLZ',
  new RegExp('\bTHANKS\b', 'g'), 'THX',
  new RegExp('\bOH MY (GOD|GOSH)\b', 'g'), 'OMG',
  new RegExp('\bATE\b', 'g'), 'EATED',
  new RegExp('\bSAID\b', 'g'), 'SED',
  new RegExp('\bSERIOUSLY\b', 'g'), 'SRSLY',
  new RegExp('\bKNOW\b', 'g'), 'KNOE',
  new RegExp('\bLOVE\b', 'g'), 'LUV',
  new RegExp('\bHELP\b', 'g'), 'HALP',
  new RegExp('\bMAYBE\b', 'g'), 'MEBBE',
  new RegExp('\bWAS\b', 'g'), 'WUZ',
  new RegExp('\bOF\b', 'g'), 'OV',
  new RegExp('\bOH\b', 'g'), 'O',
  new RegExp('\bREALLY\b', 'g'), 'RLY',
  new RegExp('\bGREAT\b', 'g'), 'GRAET',
  new RegExp('\bMY\b', 'g'), 'MAH',
  new RegExp('\b(HELLO|HI)\b', 'g'), 'HAI',
*/
  new RegExp('THI', 'g'), 'TI',
  new RegExp('\bKN', 'g'), 'N',

  new RegExp('([^ ])SE(\b|[^AEIOU])', 'g'), '$1ZE$2',
  new RegExp('IES\b', 'g'), 'EHS',
  new RegExp('TION(S?)\b', 'g'), 'SHUN',
  new RegExp('LE\b', 'g'), 'L',
  new RegExp('IENDS\b', 'g'), 'ENZ',
  new RegExp('([^R])ING\b', 'g'), '$1IN',
  new RegExp('I([KM])E\b', 'g'), 'IE$1',
  new RegExp('ER( [^AEIOU]|$)', 'g'), 'AH$1',
  new RegExp('ORE\b', 'g'), 'OAR',
  new RegExp('IE\b', 'g'), 'EE',
  new RegExp('AIR\b', 'g'), 'EH',
  new RegExp('AIN\b', 'g'), 'ANE',
  new RegExp('IEF\b', 'g'), 'EEF',
  new RegExp('TY\b', 'g'), 'TI',
  new RegExp('NESS\b', 'g'), 'NES',
  new RegExp('([^ AEIOU])E([RD])\b', 'g'), '$1$2',
  new RegExp('IC\b', 'g'), 'IK',
  new RegExp('VE\b', 'g'), 'V',
  new RegExp('FORE\b', 'g'), 'FOA',
  new RegExp('(O[^ AEIOU])E\b', 'g'), '$1',

  new RegExp('\bPH([AEIOU])', 'g'), 'F$1',
  new RegExp('([^AEIOU ])IR', 'g'), '$1UR',
  new RegExp('([^AEIOU ])S\b', 'g'), '$1Z',
  new RegExp('([^ AEIOU]) OV\b', 'g'), '$1A',

  new RegExp('N\'T', 'g'), 'NT',
  new RegExp('OAR', 'g'), 'OR',
  new RegExp('IGHT', 'g'), 'ITE',
  new RegExp('([AEIOU])S([BDFJV])', 'g'), '$1Z$2',
  new RegExp('CEIV', 'g'), 'CEEV',
  new RegExp('AUGHT', 'g'), 'AWT',
  new RegExp('OO', 'g'), 'U',
  new RegExp('U([^ AEIOU])E', 'g'), 'OO$1',
  new RegExp('U([^ AEIOU]I)', 'g'), 'OO$1',
  new RegExp('CIOUS', 'g'), 'SHUS',
  new RegExp('OUCH', 'g'), 'OWCH',
  new RegExp('ISON', 'g'), 'ISUN',
  new RegExp('OIS', 'g'), 'OYZ',

  new RegExp('\bSEAR', 'g'), 'SER',
  new RegExp('\bSEA', 'g'), 'SEE',
  new RegExp('\bGOD', 'g'), 'CEILING CAT',
  new RegExp('\bHEAVEN', 'g'), 'CEILING',

  new RegExp('([AEIOU])[SZ]E', 'g'), '$1Z',

  new RegExp('\bI AM\b', 'g'), 'I',
  new RegExp('\bIZ A\b', 'g'), 'IS',
  new RegExp('\bHAZ NO\b', 'g'), 'NO HAZ',
  new RegExp('\bDO YOU\b', 'g'), 'YOU',
  new RegExp('\bA ([A-Z]+)\b', 'g'), '$1',
  new RegExp('\bI IS\b', 'g'), 'IM'
  ];
